<?php

/* DO NOT MODIFY THIS FILE. OVERRIDE VALUES USING config.inc.php */

$dbhost='HOSTNAME';
//$dbhost=':/var/run/mysql/mysql.sock';
$dbuser='dbusername';
$dbpass='dbpassword';
$dbdata='dbdatabase';
$dbpref='tableprefix';

$repodir="/tmp";
$enablefilelist=true;
$updatepassword='';

?>
