<b>21/dec/2023</b><br>
I added the SlackDCE repository (http://slackdce.radioclub.ar/) which aims to provide a pre-built package for every entry in SlackBuilds.org - targeting 64bit Slackware 15.0. Read their manifesto at <a href="http://slackdce.radioclub.ar/slackdce/README.txt" target="_blank">http://slackdce.radioclub.ar/slackdce/README.txt</a><br/>
<br>
<b>05/mar/2023</b><br>
I disabled the Guest Book, sorry. Spammers kept polluting it and I got fed up with manual database edits. If you want to share your feedback, please post on <a href="https://alien.slackbook.org/blog/mirror-for-slackpkg-and-slakfinder/">Alien Pastures Blog</a>.<br/>
<br>
<b>27/jan/2023</b><br>
I removed the SlackAr repository after the Slackware Argentina community deleted that repository (previously at http://slack.ar/slackware/15.0/x86_64/) following a difference of opinion with the repo maintainer.<br/>
<br>
<b>25/jan/2023</b><br>
The first spammer showed up. I deleted the guest book entry but this PHP code is not using any kind of spam fighting and I am not going to add it. If more spammers show up I will have to disable the guest book.<br/>
<br>
<b>10/jan/2023</b><br>
Onboarding several new 3rd-party repositories forced me to drop the database a couple of times and modify the database scheme to deal with SQL errors.<br> Apologies for any inconvenience.<br/>
<br>
<b>08/jan/2023</b><br>
Re-implementation of the slakfinder.org web site code.<br/>
<br>
