<?php
# configuration
include_once 'inc/config_defs.inc.php';
include_once 'config.inc.php';
include_once 'inc/defrepo.inc.php';
include_once 'inc/repolist.inc.php';
# libraries
include_once 'libs/utils.inc.php';
include_once 'libs/database.inc.php';
include_once 'libs/mysql.inc.php';
include_once 'libs/internet.inc.php';
include_once 'libs/repository.inc.php';
include_once 'libs/package.inc.php';
include_once 'libs/filelist.inc.php';
include_once 'libs/xml.inc.php';
include_once 'libs/history.inc.php';
include_once 'libs/guestbook.inc.php';
include_once 'libs/stats.inc.php';
